@@ -33,6 +33,7 @@ import javax.swing.Icon;
 import javax.swing.ImageIcon;
 import javax.swing.JPanel;
 import javax.swing.plaf.metal.MetalCheckBoxIcon;
+import uk.ac.starlink.hapi.HapiTableLoadDialog;
 import uk.ac.starlink.table.gui.FileChooserTableLoadDialog;
 import uk.ac.starlink.table.gui.FilestoreTableLoadDialog;
 import uk.ac.starlink.table.gui.SQLTableLoadDialog;
@@ -86,6 +87,7 @@ public class ResourceIcon implements Icon {
         ESA_LOGO = makeIcon( "esa48.png" ),
         VIZIER_LOGO = makeIcon( "vizier_logo.png" ),
         EU_LOGO = makeIcon( "eu48.png" ),
+        EUROPLANET_LOGO = makeIcon( "europlanet48.png" ),
 
         /* Generic actions. */
         CLOSE = makeIcon( "multiply4.png"),
@@ -99,6 +101,8 @@ public class ResourceIcon implements Icon {
         FITS = makeIcon( "fits1.png" ),
         COPY = makeIcon( "Copy24.png" ),
         REDO = makeIcon( "Redo24.png" ),
+        PAUSE = makeIcon( "Pause24.png" ),
+        SCROLL = makeIcon( "History24.png" ),
         ADD = makeIcon( "Plus1.png" ),
         SUBTRACT = makeIcon( "Minus1.png" ),
         DELETE = makeIcon( "trash2.png" ),
@@ -109,13 +113,17 @@ public class ResourceIcon implements Icon {
         REVEAL = makeIcon( "true.png" ),
         HIDE_ALL = makeIcon( "falseAll2.png" ),
         REVEAL_ALL = makeIcon( "trueAll2.png" ),
+        HIDE_ALL_TINY = makeIcon( "falseAllTiny.png" ),
+        REVEAL_ALL_TINY = makeIcon( "trueAllTiny.png" ),
         MODIFY = makeIcon( "redo3.png" ),
         SEARCH = makeIcon( "search2.png" ),
         LOG = makeIcon( "book3.png" ),
         CLEAR = makeIcon( "newdoc1.png" ),
         HIDE_WINDOWS = makeIcon( "hide1.png" ),
         SCROLLER = makeIcon( "scroll2.png" ),
+        PARALLEL = makeIcon( "parallel1.png" ),
         STILTS = makeIcon( "stilts.png" ),
+        EDIT = makeIcon( "pencil.png" ),
 
         /* Windows. */
         CONTROL = makeIcon( "controlw.png" ),
@@ -193,6 +201,7 @@ public class ResourceIcon implements Icon {
         MOVE_DOWN = makeIcon( "Down2.png" ),
         EQUATION = makeIcon( "xeq.png" ),
         EXPLODE = makeIcon( "explode.png" ),
+        COLLAPSE = makeIcon( "collapse.png" ),
         ADDSKY = makeIcon( "addsky1.png" ),
         COLOR_LOG = makeIcon( "logred2.png" ),
         XLOG = makeIcon( "xlog.png" ),
@@ -251,6 +260,9 @@ public class ResourceIcon implements Icon {
         WARNING = makeIcon( "warning_triangle.png" ),
         APPROVE_ALL = makeIcon( "approve_all.png" ),
         MEASURE = makeIcon( "measure.png" ),
+        LOCK = makeIcon( "lock2.png" ),
+        QAPPROX = makeIcon( "qapprox.png" ),
+        RESET_AUTH = makeIcon( "rublock.png" ),
 
         /* Plot2 icons. */
         UP_DOWN = makeIcon( "updown8.png" ),
@@ -259,10 +271,14 @@ public class ResourceIcon implements Icon {
         PLOT_PAIR = makeIcon( "pairplot.png" ),
         PLOT_QUAD = makeIcon( "quadplot.png" ),
         PLOT_HISTO = makeIcon( "histoplot.png" ),
+        PLOT_AREA = makeIcon( "areaplot.png" ),
+        PLOT_VECTOR = makeIcon( "vectorplot.png" ),
+        PLOT_MATRIX = makeIcon( "pm1.png" ),
         PLOT2_PLANE = makeIcon( "plot2plane.png" ),
         PLOT2_SKY = makeIcon( "plot2sky.png" ),
         PLOT2_CUBE = makeIcon( "plot2cube.png" ),
         PLOT2_SPHERE = makeIcon( "plot2sphere.png" ),
+        PLOT2_MATRIX = makeIcon( "plot2matrix.png" ),
         PLOT2_TIME = makeIcon( "plot2time.png" ),
         PLOT2_HISTOGRAM = makeIcon( "plot2hist.png" ),
         HISTOBARS = makeIcon( "histobars.png" ),
@@ -676,6 +692,8 @@ public class ResourceIcon implements Icon {
                          new SsapTableLoadDialog().getIcon() );
         putMap( nameMap, "TAP_DIALOG",
                          new TapTableLoadDialog().getIcon() );
+        putMap( nameMap, "HAPI",
+                         new HapiTableLoadDialog().getIcon() );
         putMap( nameMap, "REGISTRY_DIALOG",
                          new Ri1RegistryTableLoadDialog().getIcon() );
         putMap( nameMap, "HELP_TOC",
@@ -719,7 +737,14 @@ public class ResourceIcon implements Icon {
         putMap( nameMap, "ADD_PLOT_DATA", toAddIcon( PLOT_DATA ) );
         putMap( nameMap, "ADD_PLOT_PAIR", toAddIcon( PLOT_PAIR ) );
         putMap( nameMap, "ADD_PLOT_QUAD", toAddIcon( PLOT_QUAD ) );
+        putMap( nameMap, "ADD_PLOT_MATRIX", toAddIcon( PLOT_MATRIX ) );
+        putMap( nameMap, "ADD_PLOT_AREA", toAddIcon( PLOT_AREA ) );
         putMap( nameMap, "ADD_PLOT_HISTO", toAddIcon( PLOT_HISTO ) );
+        putMap( nameMap, "ADD_PLOT_HEALPIX", toAddIcon( TTRI.PLOT_HEALPIX ) );
+        putMap( nameMap, "ADD_PLOT_SPECTRO", toAddIcon( TTRI.PLOT_SPECTRO ) );
+        putMap( nameMap, "ADD_PLOT_XYARRAY", toAddIcon( PLOT_VECTOR ) );
+        putMap( nameMap, "ADD_PLOT_FUNCTION", toAddIcon( TTRI.PLOT_FUNCTION ) );
+        putMap( nameMap, "ADD_PLOT_SKYGRID", toAddIcon( TTRI.PLOT_SKYGRID ) );
         putMap( nameMap, "ADD_FORM_MARK", toAddIcon( TTRI.FORM_MARK ) );
         putMap( nameMap, "ADD_FORM_SIZE", toAddIcon( TTRI.FORM_SIZE ) );
         putMap( nameMap, "ADD_FORM_SIZEXY", toAddIcon( TTRI.FORM_SIZEXY ) );
@@ -736,6 +761,8 @@ public class ResourceIcon implements Icon {
                          toAddIcon( TTRI.FORM_LINEARFIT ) );
         putMap( nameMap, "ADD_FORM_QUANTILE", toAddIcon( TTRI.FORM_QUANTILE ) );
         putMap( nameMap, "ADD_PLOT_LABEL", toAddIcon( TTRI.PLOT_LABEL ) );
+        putMap( nameMap, "ADD_PLOT_AREALABEL",
+                         toAddIcon( TTRI.PLOT_AREALABEL ) );
         putMap( nameMap, "ADD_PLOT_CONTOUR", toAddIcon( TTRI.PLOT_CONTOUR ) );
         putMap( nameMap, "ADD_FORM_GRID", toAddIcon( TTRI.FORM_GRID ) );
         putMap( nameMap, "ADD_FORM_SKYDENSITY",
@@ -762,6 +789,10 @@ public class ResourceIcon implements Icon {
                          toSaveIcon( TTRI.FORM_HISTOGRAM ) );
         putMap( nameMap, "IMPORT_FORM_HISTOGRAM",
                          toImportIcon( TTRI.FORM_HISTOGRAM ) );
+        putMap( nameMap, "SAVE_FORM_GRID",
+                         toSaveIcon( TTRI.FORM_GRID ) );
+        putMap( nameMap, "IMPORT_FORM_GRID",
+                         toImportIcon( TTRI.FORM_GRID ) );
 
         return nameMap;
     }
